<?php

/**
 * This file contains the \QUI\Controls\Contextmenu\Bar
 */

namespace QUI\Controls\Contextmenu;

use QUI;

/**
 * ContextBar
 *
 * @author  www.pcsg.de (Henning Leutz)
 */
class Bar extends QUI\QDOM
{
    /**
     * subitems
     *
     * @var array
     */
    private array $items = [];

    /**
     * Constructor
     *
     * @param array $settings
     */
    public function __construct(array $settings)
    {
        $this->setAttributes($settings);
        $this->setAttribute('type', 'qui/controls/contextmenu/Bar');
    }

    /**
     * Add an item
     *
     * @param BarItem|MenuItem $Itm
     */
    public function appendChild(BarItem|MenuItem $Itm): void
    {
        $this->items[] = $Itm;
    }

    /**
     * Returns the name
     *
     * @return string
     */
    public function getName(): string
    {
        return $this->getAttribute('name');
    }

    /**
     * Returns a specific child
     *
     * @param string $name - name of the item / child
     * @return bool|BarItem|MenuItem
     */
    public function getElementByName(string $name): bool|BarItem|MenuItem
    {
        foreach ($this->items as $Item) {
            if ($name == $Item->getName()) {
                return $Item;
            }
        }

        return false;
    }

    /**
     * Return a children by path
     *
     * @param string $path - /child/child/child/
     *
     * @return BarItem|Bar
     */
    public function getElementByPath(string $path): BarItem|MenuItem
    {
        $path = explode('/', $path);
        $Parent = $this;

        foreach ($path as $parent) {
            $_Parent = $Parent->getElementByName($parent);

            if ($_Parent) {
                $Parent = $_Parent;
            }
        }

        return $Parent;
    }

    /**
     * Returns all children / items
     *
     * @return array
     */
    public function getChildren(): array
    {
        return $this->items;
    }

    /**
     * Parse to array
     *
     * @return array
     */
    public function toArray(): array
    {
        $result = [];

        foreach ($this->items as $Itm) {
            $Itm->setParent($this);
            $result[] = $Itm->toArray();
        }

        return $result;
    }
}
