<?php

/**
 * This file contains the \QUI\Controls\Contextmenu\MenuItem
 */

namespace QUI\Controls\Contextmenu;

use QUI;
use QUI\Controls\Buttons\Button;

/**
 * ContextMenuItem
 *
 * @author  www.pcsg.de (Henning Leutz)
 */
class MenuItem extends QUI\QDOM
{
    /**
     * subitems
     *
     * @var array
     */
    private array $items = [];

    /**
     * Parent Object
     *
     * @var BarItem|Button|MenuItem|null
     */
    private Button|MenuItem|BarItem|null $Parent = null;

    /**
     * Disable status
     *
     * @var bool
     */
    private bool $disabled = false;

    /**
     * Constructor
     *
     * @param array $settings
     */
    public function __construct(array $settings = [])
    {
        $this->setAttributes($settings);
        $this->setAttribute('type', 'qui/controls/contextmenu/Item');
    }

    /**
     * Set parent
     *
     * @param BarItem|Button|MenuItem $parent
     */
    public function setParent(Button|MenuItem|BarItem $parent): void
    {
        $this->Parent = $parent;
    }

    /**
     * Sort the items / children
     */
    public function sortChildren(): void
    {
        $_children = [];
        $children = $this->items;

        foreach ($children as $Itm) {
            $_children[$Itm->getAttribute('text')] = $Itm;
        }

        ksort($_children);

        $this->items = $_children;
    }

    /**
     * Add a child / item
     *
     * @param MenuItem|Separator $child
     */
    public function appendChild(MenuItem|Separator $child): void
    {
        $this->items[] = $child;
    }

    /**
     * Remove a child item
     *
     * @param string $name - Name of the child
     */
    public function removeChild(string $name): void
    {
        $items = [];

        foreach ($this->items as $Item) {
            if ($name != $Item->getName()) {
                $items[] = $Item;
            }
        }

        $this->items = $items;
    }

    /**
     * Returns all children / items
     *
     * @return array
     */
    public function getChildren(): array
    {
        return $this->items;
    }

    /**
     * Returns a specific child / item
     *
     * @param string $name - Name of the child / item
     * @return bool|MenuItem
     */
    public function getElementByName(string $name): MenuItem|bool
    {
        foreach ($this->items as $Item) {
            if ($name == $Item->getName()) {
                return $Item;
            }
        }

        return false;
    }

    /**
     * Returns the name
     *
     * @return string
     */
    public function getName(): string
    {
        return $this->getAttribute('name');
    }

    /**
     * disable this item
     */
    public function setDisable(): void
    {
        $this->disabled = true;
    }

    /**
     * is the item disabled?
     */
    public function isDisable(): bool
    {
        if ($this->disabled) {
            return true;
        }

        return false;
    }

    /**
     * enable this item
     */
    public function setEnable(): void
    {
        $this->disabled = false;
    }

    /**
     * Is this item enabled?
     */
    public function isEnable(): bool
    {
        if ($this->disabled) {
            return false;
        }

        return true;
    }

    /**
     * Parse as array
     *
     * @return array
     */
    public function toArray(): array
    {
        $result = $this->getAttributes();
        $result['items'] = [];

        /*
        if ( $this->getAttribute( 'onClick' ) ) {
            $result['events']['onClick'] = $this->getAttribute( 'onClick' );
        }

        if ( $this->getAttribute( 'onMouseDown' ) ) {
            $result['events']['onMouseDown'] = $this->getAttribute( 'onMouseDown' );
        }

        if ( $this->getAttribute( 'onMouseUp' ) ) {
            $result['events']['onMouseUp'] = $this->getAttribute( 'onMouseUp' );
        }
        */

        foreach ($this->items as $Itm) {
            $Itm->setParent($this);
            $result['items'][] = $Itm->toArray();
        }

        return $result;
    }
}
