<?php

/**
 * This file contains the \QUI\Controls\Sitemap\Map
 */

namespace QUI\Controls\Sitemap;

use QUI;

/**
 * Sitemap
 *
 * @author www.pcsg.de (Henning Leutz)
 */
class Map extends QUI\QDOM
{
    /**
     * Sub Items
     *
     * @var Item[]
     */
    private array $items = [];

    /**
     * Constructor
     *
     * @param array $settings
     */
    public function __construct(array $settings = [])
    {
        $this->setAttributes($settings);
    }

    /**
     * Add a child / item
     *
     * @param Item $itm
     */
    public function appendChild(Item $itm): void
    {
        $this->items[] = $itm;
    }

    /**
     * Returns the name
     *
     * @return string
     */
    public function getName(): string
    {
        return $this->getAttribute('name');
    }

    /**
     * Return a children by its name
     *
     * @param $name
     * @return null|Item
     */
    public function getChildrenByName($name): ?Item
    {
        foreach ($this->items as $Item) {
            if ($name === $Item->getAttribute('name')) {
                return $Item;
            }
        }

        return null;
    }

    /**
     * Return the map as an array
     *
     * @return array
     */
    public function toArray(): array
    {
        $result = $this->getAttributes();
        $children = [];

        foreach ($this->items as $Item) {
            $children[] = $Item->toArray();
        }

        $result['items'] = $children;

        return $result;
    }
}
