<?php

/**
 * This file contains \QUI\Controls\Windows\Window
 */

namespace QUI\Controls\Windows;

use QUI;
use QUI\Controls\Buttons\Button;

/**
 * Window control class
 *
 * @author  www.pcsg.de (Henning Leutz)
 */
class Window extends QUI\QDOM
{
    /**
     * categories
     *
     * @var array
     */
    protected array $categories = [];

    /**
     * buttons
     *
     * @var array
     */
    protected array $buttons = [];

    /**
     * constructor
     *
     * @param array $settings
     */
    public function __construct(array $settings = [])
    {
        $this->setAttributes($settings);
    }

    /**
     * Add a category
     *
     * @param Button $Btn
     */
    public function appendCategory(Button $Btn): void
    {
        $this->categories[] = $Btn;
    }

    /**
     * Return the Categories
     *
     * @return array
     */
    public function getCategories(): array
    {
        return $this->categories;
    }

    /**
     * Remove all categories
     */
    public function clearCategories(): void
    {
        $this->categories = [];
    }

    /**
     * Add a button
     *
     * @param Button $Btn
     */
    public function appendButton(Button $Btn): void
    {
        $this->buttons[] = $Btn;
    }

    /**
     * Return the Buttons
     *
     * @return array
     */
    public function getButtons(): array
    {
        return $this->buttons;
    }

    /**
     * Return the window as an array
     *
     * @return array
     */
    public function toArray(): array
    {
        $result = $this->getAttributes();

        $result['categories'] = [];
        $result['buttons'] = [];

        foreach ($this->categories as $Itm) {
            $Itm->setParent($this);
            $result['categories'][] = $Itm->toArray();
        }

        foreach ($this->buttons as $Itm) {
            $Itm->setParent($this);
            $result['buttons'][] = $Itm->toArray();
        }

        return $result;
    }
}
